<?php
namespace Crm\Blog\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Crm\Blog\Events\BlogAction as BlogActionEvent;
use Crm\Blog\Models\Blog;

class BlogAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $blog;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param BlogActionEvent $blog
     */
    public function __construct(BlogActionEvent $blog)
    {
        $this->action = $event->action;
        $this->blog = $blog;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Blog Approved - ' . config('app.name'))
            ->view('blog::blog.email.action', ['data' => $this->blog]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
